/**
  ******************************************************************************
  * @file    stm8l10x_rst.c
  * @author  MCD Application Team
  * @version V1.2.1
  * @date    30-September-2014
  * @brief   This file contains all the functions for the RST peripheral.
  ******************************************************************************
  */

// Includes ------------------------------------------------------------------

#include "stm8l10x_rst.h"

 // @addtogroup STM8L10x_StdPeriph_Driver

/** @defgroup RST 
  * @brief RST driver modules
  * @{
  */ 
  
// Private typedef -----------------------------------------------------------
#define RST_CR_MASK  0xD0 /*!< Enable the GPIO */
// Private macro -------------------------------------------------------------
// Private variables ---------------------------------------------------------
// Private function prototypes -----------------------------------------------
// Private Constants ---------------------------------------------------------

  // * @addtogroup RST_Private_Functions

/**
  * @brief   Checks whether the specified RST flag is set or not.
  * @param   RST_Flag : specify the reset flag to check.
  *          This parameter can be one of the following values:
  *            @arg RST_FLAG_POR_PDR: POR reset flag
  *            @arg RST_FLAG_SWIMF: SWIM reset flag
  *            @arg RST_FLAG_ILLOPF: Illegal opcode reset flag
  *            @arg RST_FLAG_IWDGF: Independent watchdog reset flag 
  *            @arg RST_FLAG_BORF: BOR reset flag
  * @retval  The new state of RST_Flag (SET or RESET).
  */
FlagStatus RST_GetFlagStatus(RST_Flag_TypeDef RST_Flag)
{
  // Check the parameters 
  assert_param(IS_RST_FLAG(RST_Flag));

  // Get flag status 

  return((FlagStatus)(((uint8_t)(RST->SR & RST_Flag) == (uint8_t)0x00) ? RESET : SET));
}

/**
  * @brief  Clears the specified RST flag.
  * @param  RST_Flag : specify the reset flag to clear.
  *          This parameter can be one of the following values:
  *            @arg RST_FLAG_POR_PDR: POR reset flag
  *            @arg RST_FLAG_SWIMF: SWIM reset flag
  *            @arg RST_FLAG_ILLOPF: Illegal opcode reset flag
  *            @arg RST_FLAG_IWDGF: Independent watchdog reset flag 
  *            @arg RST_FLAG_BORF: BOR reset flag  
  * @retval None
  */
void RST_ClearFlag(RST_Flag_TypeDef RST_Flag)
{
  // Check the parameters 
  assert_param(IS_RST_FLAG(RST_Flag));

  RST->SR = (uint8_t)RST_Flag;
}

/**
  * @brief  Configures the reset pad as GP output.
  * @param  None
  * @retval None
  */
void RST_GPOutputEnable(void)
{

  RST->CR = RST_CR_MASK;
}

  
  
