/**
  ******************************************************************************
  * @file    main.c
  * @author  MCD Application Team
  * @version V1.2.1
  * @date    30-September-2014
  * @brief   Main program body
  ******************************************************************************
  */

// Includes ------------------------------------------------------------------
#include "stm8l10x.h"
#include "stm8l101_eval.h"

  // * @addtogroup CLK_MasterClock
// Private typedef -----------------------------------------------------------
// Private define ------------------------------------------------------------
// Private macro -------------------------------------------------------------
// Private variables ---------------------------------------------------------
// Private function prototypes -----------------------------------------------
void Delay (uint16_t nCount);

// Private functions ---------------------------------------------------------

/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
void main(void)
{
  // configure the CCO GPIO PIN (PC4)
  GPIO_ExternalPullUpConfig(GPIOC,GPIO_Pin_4,ENABLE);

  // Initialize LEDs mounted on the EVAL board 
  STM_EVAL_LEDInit(LED2);
  STM_EVAL_LEDInit(LED3);
  STM_EVAL_LEDInit(LED4);

  // Initialize Joystick pushbutton mounted on the EVAL board 
  STM_EVAL_PBInit(BUTTON_RIGHT, BUTTON_MODE_EXTI);
  STM_EVAL_PBInit(BUTTON_LEFT, BUTTON_MODE_EXTI);
  STM_EVAL_PBInit(BUTTON_UP, BUTTON_MODE_EXTI);
  STM_EVAL_PBInit(BUTTON_DOWN, BUTTON_MODE_EXTI);
  
  enableInterrupts();

  // Select and enable Master clock output on CCO pin 
  CLK_CCOConfig(CLK_Output_ClockMaster);
  
  while (1)
  {
    // LEDs Toggle 
    STM_EVAL_LEDToggle(LED2);
    STM_EVAL_LEDToggle(LED3);
    STM_EVAL_LEDToggle(LED4);
    
    Delay((uint16_t)60000);
  }
}

/**
  * @brief  Delay.
  * @param  nCount
  * @retval None
  */
void Delay(uint16_t nCount)
{
  // Decrement nCount value 
  while (nCount != 0)
  {
    nCount--;
  }
}


#ifdef  USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: assert_param error line source number
  * @retval : None
  */
void assert_failed(uint8_t* file, uint32_t line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  // Infinite loop 
  while (1)
  {
  }
}
#endif

