/**
  ******************************************************************************
  * @file    main.c
  * @author  MCD Application Team
  * @version V1.2.1
  * @date    30-September-2014
  * @brief   Main program body
  ******************************************************************************
  */

// Includes ------------------------------------------------------------------
#include "stm8l10x.h"

  // * @addtogroup TIM2_PWM_DutyCycleConfiguration
// Private variables ---------------------------------------------------------
uint16_t CCR1_Val = 32767;
uint16_t CCR2_Val = 16383;
// Private defines -----------------------------------------------------------
// Private function prototypes -----------------------------------------------
static void TIM2_Config(void);
// Private functions ---------------------------------------------------------

/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
void main(void)
{
  // TIM2 Configuration ------------------------------------------------------
  TIM2_Config();
  
  while (1)
  {}
}

/**
  * @brief  Configure TIM2 peripheral
  * @param  None
  * @retval None
  */
static void TIM2_Config(void)
{
  // Enable TIM2 clock 
  CLK_PeripheralClockConfig(CLK_Peripheral_TIM2, ENABLE);
  
  // Config TIM2 Channel 1 and channel 2 pins 
  GPIO_Init(GPIOB, GPIO_Pin_0 | GPIO_Pin_2, GPIO_Mode_Out_PP_High_Fast);

  // Time base configuration 
  TIM2_TimeBaseInit(TIM2_Prescaler_1, TIM2_CounterMode_Up, 65535);

  // PWM1 Mode configuration: Channel1  
  TIM2_OC1Init(TIM2_OCMode_PWM1, TIM2_OutputState_Enable, CCR1_Val, TIM2_OCPolarity_High, TIM2_OCIdleState_Set);
  TIM2_OC1PreloadConfig(ENABLE);

  // PWM1 Mode configuration: Channel2  
  TIM2_OC2Init(TIM2_OCMode_PWM1, TIM2_OutputState_Enable,CCR2_Val, TIM2_OCPolarity_High, TIM2_OCIdleState_Set);
  TIM2_OC2PreloadConfig(ENABLE);

  TIM2_ARRPreloadConfig(ENABLE);

  // Enable TIM2 outputs 
  TIM2_CtrlPWMOutputs(ENABLE);
  
  // TIM2 enable counter 
  TIM2_Cmd(ENABLE);
}

#ifdef  USE_FULL_ASSERT
/**
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: assert_param error line source number
  * @retval : None
  */
void assert_failed(uint8_t* file, uint32_t line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  // Infinite loop 
  while (1)
  {
  }
}
#endif


