/**
  ******************************************************************************
  * @file    main.c
  * @author  MCD Application Team
  * @version V1.2.1
  * @date    30-September-2014
  * @brief   Main program body
  ******************************************************************************
  */

// Includes ------------------------------------------------------------------
#include "stm8l10x.h"
#include "stdio.h"
  // * @addtogroup USART_Printf
// Private typedef -----------------------------------------------------------
// Private define ------------------------------------------------------------
#ifdef _RAISONANCE_
 #define PUTCHAR_PROTOTYPE int putchar (char c)
 #define GETCHAR_PROTOTYPE int getchar (void)
#elif defined (_COSMIC_)
 #define PUTCHAR_PROTOTYPE char putchar (char c)
 #define GETCHAR_PROTOTYPE char getchar (void)
#else /* _IAR_ */
 #define PUTCHAR_PROTOTYPE int putchar (int c)
 #define GETCHAR_PROTOTYPE int getchar (void)
#endif

// Private macro -------------------------------------------------------------
// Private variables ---------------------------------------------------------
// Private function prototypes -----------------------------------------------
static void USART_Config(void);

// Private functions ---------------------------------------------------------

/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
void main(void)
{
    // USART Configuration ---------------------------------------------------
    USART_Config();
    
    // Output a message on Hyperterminal using printf function 
    printf("\n\rUSART Example: retarget the C library printf function to the USART\n\r");

    while (1)
    {}
}

/**
  * @brief  Configure USART peripheral to print characters on Hyperteminal
  * @param  None
  * @retval None
  */
static void USART_Config(void)
{
    // High speed internal clock prescaler: 1
    CLK_MasterPrescalerConfig(CLK_MasterPrescaler_HSIDiv1);
 
     // Set the USART RX and USART TX at high level
    GPIO_ExternalPullUpConfig(GPIOC,GPIO_Pin_3|GPIO_Pin_4, ENABLE);
    
    // Enable USART clock 
    CLK_PeripheralClockConfig(CLK_Peripheral_USART, ENABLE);
    
    USART_DeInit();
    // USART configuration ------------------------------------------------------
    /* USART configured as follow:
          - BaudRate = 115200 baud  
          - Word Length = 8 Bits
          - One Stop Bit
          - No parity
          - Receive and transmit enabled
    */
     USART_Init((uint32_t)115200, USART_WordLength_8D, USART_StopBits_1,
                USART_Parity_No, (USART_Mode_TypeDef)(USART_Mode_Rx | USART_Mode_Tx));
}

/**
  * @brief  Retargets the C library printf function to the USART.
  * @param  c Character to send
  * @retval char Character sent
  */
PUTCHAR_PROTOTYPE
{
  // Write a character to the USART 
  USART_SendData8(c);
  
  // Loop until the end of transmission 
  while (USART_GetFlagStatus(USART_FLAG_TXE) == RESET);

  return (c);
}


#ifdef  USE_FULL_ASSERT
/**
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: assert_param error line source number
  * @retval : None
  */
void assert_failed(uint8_t* file, uint32_t line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  // Infinite loop 
  while (1)
  {
  }
}
#endif


